@@ -384,6 +384,8 @@ def indexacion(df,mini,maxi):
     years2=[]
     for i in range(mini,maxi,10):
         years1.append(i)
+    for j in range(mini,maxi,5):
+        years2.append(j)
     if maxi not in years1:
         years1.append(maxi)
     if maxi not in years2:
